"use strict";

var _interopRequireDefault =
/*#__PURE__*/
require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _ramda =
/*#__PURE__*/
require("ramda");

var _isFunction =
/*#__PURE__*/
_interopRequireDefault(
/*#__PURE__*/
require("./isFunction"));

var _headArg =
/*#__PURE__*/
_interopRequireDefault(
/*#__PURE__*/
require("./headArg"));

/**
 * If the first argument is a function then we apply the function with args that are passed as the second argument.
 * If the first argument is not a function then we return it as it is.
 *
 * @func
 * @category Function
 *
 * @param {any} x 	Function or value
 * @param {array} args 	Array of arguments
 * @returns {any}
 *
 * @example
 * 		const ref = { current: null };
 * 		const getRef = always(ref);
 * 		const createRef = (current) => ({ current });
 *
 * 		R_.applyIfFunction(ref, []); // { current: null }
 * 		R_.applyIfFunction(getRef, []); // { current: null }
 * 		R_.applyIfFunction(createRef, [document.body]); // {"current": [object HTMLBodyElement]}
 *
 * @sig a|(*... -> a) -> [*] -> a
 */
var applyIfFunction =
/*#__PURE__*/
(0, _ramda.ifElse)(_isFunction.default, _ramda.apply, _headArg.default);
var _default = applyIfFunction;
exports.default = _default;