"use strict";

var _interopRequireDefault =
/*#__PURE__*/
require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _ramda =
/*#__PURE__*/
require("ramda");

var _notNil =
/*#__PURE__*/
_interopRequireDefault(
/*#__PURE__*/
require("./notNil"));

var _alwaysNull =
/*#__PURE__*/
_interopRequireDefault(
/*#__PURE__*/
require("./alwaysNull"));

/**
 * Call apply on function if the function is defined. Otherwise do nothing and return null.
 *
 * @func
 * @category Function
 *
 * @param {Function} fn The function which will be called with `args` when defined
 * @param {Array} args The arguments to call `fn` with
 * @return {*} result The result, equivalent to `fn(...args)` or null
 * @example
 *
 *        const nums = [1, 2, 3];
 *        R_.applyIfNotNil(R.sum, nums) // 6
 *        R_.applyIfNotNil(undefined, nums) // null
 *
 * @sig (*... -> a) -> [*] -> a
 */
var applyIfNotNil =
/*#__PURE__*/
(0, _ramda.ifElse)(_notNil.default, _ramda.apply, _alwaysNull.default);
var _default = applyIfNotNil;
exports.default = _default;