"use strict";

var _interopRequireDefault =
/*#__PURE__*/
require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _ramda =
/*#__PURE__*/
require("ramda");

var _mapKeysAndValues =
/*#__PURE__*/
_interopRequireDefault(
/*#__PURE__*/
require("./mapKeysAndValues"));

var _toCamelCase =
/*#__PURE__*/
_interopRequireDefault(
/*#__PURE__*/
require("./toCamelCase"));

var _isNotNilObject =
/*#__PURE__*/
_interopRequireDefault(
/*#__PURE__*/
require("./isNotNilObject"));

var _isArray =
/*#__PURE__*/
_interopRequireDefault(
/*#__PURE__*/
require("./isArray"));

var _isFunction =
/*#__PURE__*/
_interopRequireDefault(
/*#__PURE__*/
require("./isFunction"));

// Must be written as arrow `x => camelizeKeys(x)` due to recursion
// prettier-ignore
var camelizeObj =
/*#__PURE__*/
(0, _mapKeysAndValues.default)(
/*#__PURE__*/
(0, _ramda.juxt)([
/*#__PURE__*/
(0, _ramda.o)(_toCamelCase.default, _ramda.head),
/*#__PURE__*/
(0, _ramda.o)(function (x) {
  return camelizeKeys(x);
}, _ramda.last)]));
var camelizeArray =
/*#__PURE__*/
(0, _ramda.map)(function (x) {
  return camelizeKeys(x);
});
/**
 * Recursively camelize all keys within an object or array
 *
 * @func
 * @category Object
 *
 * @param {any} x Object to transform
 * @return {any}
 * @example
 *
 *      camelizeKeys({
 *          'co-obj': { co_string: 'foo' },
 *          'co-array': [0, null, { 'f-f': 'ff' }],
 *          'co-number': 1,
 *          'co-string': '1',
 *          'co-fn': head,
 *      });
 *
 *      // {
 *      //     coArray: [
 *      //         0,
 *      //         null,
 *      //         {
 *      //             fF: 'ff'
 *      //         }
 *      //     ],
 *      //     coFn: [Function],
 *      //     coNumber: 1,
 *      //     coObj: {
 *      //         coString: 'foo'
 *      //     },
 *      //     coString: '1'
 *      // }
 *
 */
// prettier-ignore

var camelizeKeys =
/*#__PURE__*/
(0, _ramda.cond)([[_isArray.default, camelizeArray], [_isFunction.default, _ramda.identity], [_isNotNilObject.default, camelizeObj], [_ramda.T, _ramda.identity]]);
var _default = camelizeKeys;
exports.default = _default;