"use strict";

var _interopRequireDefault =
/*#__PURE__*/
require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _ramda =
/*#__PURE__*/
require("ramda");

var _applyCompose =
/*#__PURE__*/
_interopRequireDefault(
/*#__PURE__*/
require("./applyCompose"));

var _xPairs =
/*#__PURE__*/
_interopRequireDefault(
/*#__PURE__*/
require("./xPairs"));

var getPredicates =
/*#__PURE__*/
(0, _ramda.compose)(
/*#__PURE__*/
(0, _ramda.map)(
/*#__PURE__*/
(0, _ramda.juxt)([_applyCompose.default, _ramda.last])), _xPairs.default);
/**
 * Returns first result from evaluation of functions in the list, that satisfies predicate.
 * Returns `undefined` otherwise.
 *
 * @func
 * @category Function
 * @see dispatch
 *
 * @param {function} predicate Predicate that is applied to result of calling fn from `listFns` with `values`
 * @param {array} listFns List of functions
 * @param {*} values Values applied to functions from `listFns`
 * @return {any} Returns first result of calling fn from `listFns` with `values` that satisfies `predicate`.
 *
 * @example
 *
 *        const firstTruthy = R_.dispatchWith(Boolean)([
 *           prop("foo"),
 *           prop("bar"),
 *        ])
 *
 *        firstTruthy({foo: "foo", bar: false}) // "foo"
 *        firstTruthy({foo: false, bar: "bar" }) // "bar"
 *
 * @sig [a] -> b|undefined
 */

var dispatchWith =
/*#__PURE__*/
(0, _ramda.converge)(
/*#__PURE__*/
(0, _ramda.call)(_ramda.cond), [getPredicates]);
var _default = dispatchWith;
exports.default = _default;