"use strict";

var _interopRequireDefault =
/*#__PURE__*/
require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _ramda =
/*#__PURE__*/
require("ramda");

var _splitByDot =
/*#__PURE__*/
_interopRequireDefault(
/*#__PURE__*/
require("./splitByDot"));

/**
 * Determines whether a dot path on an object has a specific value
 * in `R.equals` terms.
 *
 * @func
 * @category Object
 * @param {String} path The dot path to use.
 * @param {any} eq Value for `R.equals`.
 * @param {Object} obj The object to retrieve the nested property from and compare with `eq`.
 * @return {*} True if value on dot path equals to `eq`.
 *
 * @example
 *
 *      R_.dotPathEq('a.b', 2, {a: {b: 2}}); //=> true
 *      R_.dotPathEq('a.b', 2, {c: {b: 2}}); //=> false
 *
 * @sig String -> a -> {a} -> Boolean
 *
 */
var dotPathEq =
/*#__PURE__*/
(0, _ramda.useWith)(_ramda.pathEq, [_splitByDot.default, _ramda.identity, _ramda.identity]);
var _default = dotPathEq;
exports.default = _default;